"use strict";
exports.__esModule = true;
exports.withTscErrors = void 0;
var tslib_1 = require("tslib");
var experimental_utils_1 = require("@typescript-eslint/experimental-utils");
var typescript_1 = tslib_1.__importDefault(require("typescript"));
var createRule = experimental_utils_1.ESLintUtils.RuleCreator(function (ruleName) { return ruleName; });
exports.withTscErrors = createRule({
    name: "with-tsc-errors",
    meta: {
        type: "suggestion",
        docs: {
            description: "show tsc error plugin.",
            category: "Best Practices",
            recommended: false,
            requiresTypeChecking: true
        },
        messages: {
            // see: https://eslint.org/docs/developer-guide/working-with-rules#using-message-placeholders
            message: "{{ message }}"
        },
        schema: []
    },
    defaultOptions: [],
    create: function (context) {
        var program = experimental_utils_1.ESLintUtils.getParserServices(context).program;
        // eslint-disable-next-line @typescript-eslint/no-empty-function
        var emitResults = program.emit(undefined, function () { });
        var allDiagnostics = tslib_1.__spreadArrays(typescript_1["default"].getPreEmitDiagnostics(program, program.getSourceFile(context.getFilename())), emitResults.diagnostics);
        return {
            "Program:exit": function () {
                allDiagnostics.forEach(function (diagnostic) {
                    if (diagnostic.file) {
                        var _a = diagnostic.file.getLineAndCharacterOfPosition(diagnostic.start), startLine = _a.line, startCharacter = _a.character;
                        var _b = diagnostic.file.getLineAndCharacterOfPosition(diagnostic.start + diagnostic.length), endLine = _b.line, endCharacter = _b.character;
                        var message = typescript_1["default"].flattenDiagnosticMessageText(diagnostic.messageText, "\n");
                        context.report({
                            loc: {
                                start: {
                                    line: startLine,
                                    column: startCharacter
                                },
                                end: {
                                    line: endLine,
                                    column: endCharacter
                                }
                            },
                            messageId: "message",
                            data: {
                                message: message
                            }
                        });
                    }
                });
            }
        };
    }
});
//# sourceMappingURL=with-tsc-error.js.map